@@ -55,7 +55,6 @@
 #include <sys/time.h>
 #include <time.h>
 
-#define BORDER          6
 #define AC_COLOR        "#8888FF"
 #define HIGH_COLOR      "#00ff00"
 #define LOW_COLOR       "#ffff00"
@@ -103,7 +102,8 @@ typedef struct
     GtkLabel        *rtime;
     GtkLabel        *acfan;
     GtkLabel        *temp;
-    GtkWidget        *image;
+    GtkWidget       *image;
+    GtkCssProvider  *css_provider;
 } t_battmon;
 
 typedef struct
@@ -273,6 +273,7 @@ update_apm_status(t_battmon *battmon)
     int time_remaining=0;
     gboolean acline;
     gchar buffer[128];
+    gchar *css, *color_str;
 
     static int update_time = AVERAGING_CYCLE;
     static int sum_lcapacity = 0;
@@ -599,25 +600,22 @@ battmon.c:241: for each function it appears in.)
       }
     }
 
-#if GTK_CHECK_VERSION (3, 16, 0)
+    color_str = gdk_rgba_to_string (color);
 #if GTK_CHECK_VERSION (3, 20, 0)
-    gchar *css = g_strdup_printf("progressbar trough { min-width: 4px; min-height: 4px; } \
-                                  progressbar progress { min-width: 4px; min-height: 4px; \
+    gchar * cssminsizes = "min-width: 4px; min-height: 0px";
+    if (gtk_orientable_get_orientation(GTK_ORIENTABLE(battmon->battstatus)) == GTK_ORIENTATION_HORIZONTAL)
+        cssminsizes = "min-width: 0px; min-height: 4px";
+    css = g_strdup_printf("progressbar trough { %s } \
+                                   progressbar progress { %s ; \
                                                          background-color: %s; background-image: none; }",
+                                 cssminsizes, cssminsizes,
 #else
-    gchar *css = g_strdup_printf("progressbar progress { background-color: %s; background-image: none; }",
+    css = g_strdup_printf(".progressbar progress { background-color: %s; background-image: none; }",
 #endif
-                                 gdk_rgba_to_string(color));
-    GtkCssProvider *css_provider = gtk_css_provider_new ();
-    gtk_css_provider_load_from_data (css_provider, css, strlen(css), NULL);
-    gtk_style_context_add_provider (
-        GTK_STYLE_CONTEXT (gtk_widget_get_style_context (GTK_WIDGET (battmon->battstatus))),
-        GTK_STYLE_PROVIDER (css_provider),
-        GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+                                 color_str);
+    gtk_css_provider_load_from_data (battmon->css_provider, css, strlen(css), NULL);
     g_free(css);
-#else
-    gtk_widget_override_background_color (widget, GTK_STATE_FLAG_NORMAL, color);
-#endif
+    g_free(color_str);
 
     /* alarms */
     if (!acline && charge <= battmon->options.low_percentage){
@@ -665,7 +663,6 @@ do_low_warn:
 
 static void setup_battmon(t_battmon *battmon)
 {
-    GdkPixbuf *icon;
     gint size;
 
     size = xfce_panel_plugin_get_size (battmon->plugin);
@@ -681,6 +678,12 @@ static void setup_battmon(t_battmon *battmon)
     gtk_progress_bar_set_inverted(GTK_PROGRESS_BAR(battmon->battstatus),
                                   (xfce_panel_plugin_get_orientation(battmon->plugin) == GTK_ORIENTATION_HORIZONTAL));
 
+    battmon->css_provider = gtk_css_provider_new();
+    gtk_style_context_add_provider(
+        GTK_STYLE_CONTEXT (gtk_widget_get_style_context (GTK_WIDGET (battmon->battstatus))),
+        GTK_STYLE_PROVIDER (battmon->css_provider),
+        GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+
     battmon->label = (GtkLabel *)gtk_label_new(_("Battery"));
     gtk_box_pack_start(GTK_BOX(battmon->ebox),GTK_WIDGET(battmon->label),FALSE, FALSE, 2);
 
@@ -771,7 +774,6 @@ battmon_set_mode (XfcePanelPlugin *plugin, XfcePanelPluginMode mode,
     GtkOrientation orientation;
     DBG("set_mode(%d)", mode);
 
-    if (battmon->timeoutid) g_source_remove(battmon->timeoutid);
     orientation =
       (mode != XFCE_PANEL_PLUGIN_MODE_VERTICAL) ?
       GTK_ORIENTATION_HORIZONTAL : GTK_ORIENTATION_VERTICAL;
@@ -787,7 +789,6 @@ battmon_set_mode (XfcePanelPlugin *plugin, XfcePanelPluginMode mode,
     battmon_set_labels_orientation(battmon, orientation);
     battmon_set_size(plugin, xfce_panel_plugin_get_size (plugin), battmon);
     update_apm_status( battmon );
-    battmon->timeoutid = g_timeout_add(1 * 1024, (GSourceFunc) update_apm_status, battmon);
     xfce_panel_plugin_set_small (plugin, (mode != XFCE_PANEL_PLUGIN_MODE_DESKBAR));
 
     return TRUE;
@@ -994,7 +995,6 @@ static void refresh_dialog(t_battmon_dialog *dialog)
 
     gtk_spin_button_set_value(GTK_SPIN_BUTTON(dialog->sb_low_percentage), battmon->options.low_percentage);
     gtk_spin_button_set_value(GTK_SPIN_BUTTON(dialog->sb_critical_percentage), battmon->options.critical_percentage);
-    gtk_color_button_new_with_rgba(&battmon->options.colorA);
     gtk_color_chooser_set_rgba(GTK_COLOR_CHOOSER(dialog->ac_color_button), &battmon->options.colorA);
     gtk_color_chooser_set_rgba(GTK_COLOR_CHOOSER(dialog->high_color_button), &battmon->options.colorH);
     gtk_color_chooser_set_rgba(GTK_COLOR_CHOOSER(dialog->low_color_button), &battmon->options.colorL);
@@ -1300,28 +1300,26 @@ battmon_create_options(XfcePanelPlugin *plugin, t_battmon *battmon)
     g_signal_connect (dlg, "response", G_CALLBACK (battmon_dialog_response),
                       battmon);
 
-    gtk_container_set_border_width (GTK_CONTAINER (dlg), 2);
-
     notebook = gtk_notebook_new ();
     gtk_widget_show (notebook);
-    gtk_container_set_border_width (GTK_CONTAINER(notebook), BORDER);
+    gtk_container_set_border_width (GTK_CONTAINER(notebook), 6);
     gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area(GTK_DIALOG(dlg))), GTK_WIDGET(notebook),
                         TRUE, TRUE, 0);
 
-
     /* Bar colors */
-    vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, BORDER);
-    gtk_container_set_border_width (GTK_CONTAINER(vbox), BORDER);
+    vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 6);
+    gtk_container_set_border_width (GTK_CONTAINER(vbox), 12);
 
     /* Create size group to keep widgets aligned */
     sg = gtk_size_group_new(GTK_SIZE_GROUP_HORIZONTAL);
 
-    hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, BORDER);
+    hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 12);
     gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 
     label = gtk_label_new(_("On AC:"));
     gtk_size_group_add_widget(sg,label);
     gtk_widget_set_valign(label, GTK_ALIGN_CENTER);
+    gtk_label_set_xalign (GTK_LABEL (label), 0.0f);
     gtk_box_pack_start(GTK_BOX(hbox),label,FALSE,FALSE,0);
 
     dialog->ac_color_button = gtk_color_button_new_with_rgba(&battmon->options.colorA);
@@ -1329,12 +1327,13 @@ battmon_create_options(XfcePanelPlugin *plugin, t_battmon *battmon)
     gtk_widget_show(GTK_WIDGET(dialog->ac_color_button));
     gtk_box_pack_start(GTK_BOX(hbox), GTK_WIDGET(dialog->ac_color_button), FALSE, FALSE, 0);
 
-    hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, BORDER);
+    hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 12);
     gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 
     label = gtk_label_new(_("Battery high:"));
     gtk_size_group_add_widget(sg,label);
     gtk_widget_set_valign(label, GTK_ALIGN_CENTER);
+    gtk_label_set_xalign (GTK_LABEL (label), 0.0f);
     gtk_box_pack_start(GTK_BOX(hbox),label,FALSE,FALSE,0);
 
     dialog->high_color_button = gtk_color_button_new_with_rgba(&battmon->options.colorH);
@@ -1342,12 +1341,13 @@ battmon_create_options(XfcePanelPlugin *plugin, t_battmon *battmon)
     gtk_widget_show(GTK_WIDGET(dialog->high_color_button));
     gtk_box_pack_start(GTK_BOX(hbox), GTK_WIDGET(dialog->high_color_button), FALSE, FALSE, 0);
 
-    hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, BORDER);
+    hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 12);
     gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 
     label = gtk_label_new(_("Battery low:"));
     gtk_size_group_add_widget(sg,label);
     gtk_widget_set_valign(label, GTK_ALIGN_CENTER);
+    gtk_label_set_xalign (GTK_LABEL (label), 0.0f);
     gtk_box_pack_start(GTK_BOX(hbox),label,FALSE,FALSE,0);
 
     dialog->low_color_button = gtk_color_button_new_with_rgba(&battmon->options.colorL);
@@ -1355,12 +1355,13 @@ battmon_create_options(XfcePanelPlugin *plugin, t_battmon *battmon)
     gtk_widget_show(GTK_WIDGET(dialog->low_color_button));
     gtk_box_pack_start(GTK_BOX(hbox), GTK_WIDGET(dialog->low_color_button), FALSE, FALSE, 0);
 
-    hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, BORDER);
+    hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 12);
     gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 
     label = gtk_label_new(_("Battery critical:"));
     gtk_size_group_add_widget(sg,label);
     gtk_widget_set_valign(label, GTK_ALIGN_CENTER);
+    gtk_label_set_xalign (GTK_LABEL (label), 0.0f);
     gtk_box_pack_start(GTK_BOX(hbox),label,FALSE,FALSE,0);
 
     dialog->critical_color_button = gtk_color_button_new_with_rgba(&battmon->options.colorC);
@@ -1377,14 +1378,15 @@ battmon_create_options(XfcePanelPlugin *plugin, t_battmon *battmon)
     sg = gtk_size_group_new(GTK_SIZE_GROUP_HORIZONTAL);
 
     /* Low and Critical percentage settings */
-    vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, BORDER);
-    gtk_container_set_border_width (GTK_CONTAINER(vbox), BORDER);
-    hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, BORDER);
+    vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 6);
+    gtk_container_set_border_width (GTK_CONTAINER(vbox), 12);
+    hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 12);
     gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 
     label = gtk_label_new(_("Low percentage:"));
     gtk_size_group_add_widget(sg, label);
     gtk_widget_set_valign(label, GTK_ALIGN_CENTER);
+    gtk_label_set_xalign (GTK_LABEL (label), 0.0f);
     gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
 
     dialog->sb_low_percentage = gtk_spin_button_new_with_range(1, 100, 1);
@@ -1392,12 +1394,13 @@ battmon_create_options(XfcePanelPlugin *plugin, t_battmon *battmon)
 
     /* Low battery action settings */
 
-    hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, BORDER);
+    hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 12);
     gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 
     label = gtk_label_new(_("Low battery action:"));
     gtk_size_group_add_widget(sg, label);
     gtk_widget_set_valign(label, GTK_ALIGN_CENTER);
+    gtk_label_set_xalign (GTK_LABEL (label), 0.0f);
     gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
 
     dialog->co_action_low = gtk_combo_box_text_new();
@@ -1409,11 +1412,12 @@ battmon_create_options(XfcePanelPlugin *plugin, t_battmon *battmon)
 
     /* Low battery command */
 
-    hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, BORDER);
+    hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 12);
     gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, TRUE, 0);
 
     label = gtk_label_new(_("Command:"));
     gtk_widget_set_valign(label, GTK_ALIGN_CENTER);
+    gtk_label_set_xalign (GTK_LABEL (label), 0.0f);
     gtk_size_group_add_widget(sg, label);
     gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
 
@@ -1423,12 +1427,14 @@ battmon_create_options(XfcePanelPlugin *plugin, t_battmon *battmon)
     button = gtk_button_new_with_label("...");
     gtk_box_pack_start(GTK_BOX(hbox), button, FALSE, FALSE, 0);
 
-    hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, BORDER);
+    hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 12);
+    gtk_widget_set_margin_top (GTK_WIDGET (hbox), 12);
     gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 
     label = gtk_label_new(_("Critical percentage:"));
     gtk_size_group_add_widget(sg, label);
     gtk_widget_set_valign(label, GTK_ALIGN_CENTER);
+    gtk_label_set_xalign (GTK_LABEL (label), 0.0f);
     gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
 
     dialog->sb_critical_percentage = gtk_spin_button_new_with_range(1, 100, 1);
@@ -1436,12 +1442,13 @@ battmon_create_options(XfcePanelPlugin *plugin, t_battmon *battmon)
 
     /* Critical battery action settings */
 
-    hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, BORDER);
+    hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 12);
     gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 
     label = gtk_label_new(_("Critical battery action:"));
     gtk_size_group_add_widget(sg, label);
     gtk_widget_set_valign(label, GTK_ALIGN_CENTER);
+    gtk_label_set_xalign (GTK_LABEL (label), 0.0f);
     gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
 
     dialog->co_action_critical = gtk_combo_box_text_new();
@@ -1453,11 +1460,12 @@ battmon_create_options(XfcePanelPlugin *plugin, t_battmon *battmon)
 
     /* Critical battery command */
 
-    hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, BORDER);
+    hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 12);
     gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, TRUE, 0);
 
     label = gtk_label_new(_("Command:"));
     gtk_widget_set_valign(label, GTK_ALIGN_CENTER);
+    gtk_label_set_xalign (GTK_LABEL (label), 0.0f);
     gtk_size_group_add_widget(sg, label);
     gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
 
@@ -1477,8 +1485,8 @@ battmon_create_options(XfcePanelPlugin *plugin, t_battmon *battmon)
 
     /* Create checkbox options */
 
-    vbox2 = gtk_box_new(GTK_ORIENTATION_VERTICAL, BORDER);
-    gtk_container_set_border_width (GTK_CONTAINER(vbox2), BORDER);
+    vbox2 = gtk_box_new(GTK_ORIENTATION_VERTICAL, 6);
+    gtk_container_set_border_width (GTK_CONTAINER(vbox2), 12);
 
     dialog->cb_disp_label = gtk_check_button_new_with_mnemonic(_("Display label"));
     gtk_box_pack_start(GTK_BOX(vbox2), dialog->cb_disp_label, FALSE, FALSE, 0);
